<?php
/**
 * Plugin Name: Spin Rewriter
 * Plugin URI: https://www.spinrewriter.com/wordpress-plugin
 * Description: This is the official Spin Rewriter plugin, used by thousands of marketers. It can spin and republish your old posts, or create brand new posts automatically. It also integrates all your WordPress websites directly into your Spin Rewriter account.
 * Version: 11.0.0
 * Author: Aaron Sustar
 * Author URI: https://www.aaronsustar.com/
 * Text Domain: spin-rewriter-wordpress-plugin
 * License: GPLv3
 */

$SpinRewriterWordPressPlugin_minimalRequiredPhpVersion = '5.0';

/**
 * Check the PHP version and give a useful error message if the user's version is less than the required version
 * @return boolean true if version check passed. If false, triggers an error which WP will handle, by displaying
 * an error message on the Admin page
 */
function SpinRewriterWordPressPlugin_noticePhpVersionWrong() {
    global $SpinRewriterWordPressPlugin_minimalRequiredPhpVersion;
    echo '<div class="updated fade">' .
      __('Error: Plugin "Spin Rewriter" requires a newer version of PHP to be running.', 'spin-rewriter-wordpress-plugin').
            '<br/>' . __('Minimal version of PHP required: ', 'spin-rewriter-wordpress-plugin') . '<strong>' . $SpinRewriterWordPressPlugin_minimalRequiredPhpVersion . '</strong>' .
            '<br/>' . __('Your server\'s PHP version: ', 'spin-rewriter-wordpress-plugin') . '<strong>' . phpversion() . '</strong>' .
         '</div>';
}


function SpinRewriterWordPressPlugin_PhpVersionCheck() {
    global $SpinRewriterWordPressPlugin_minimalRequiredPhpVersion;
    if (version_compare(phpversion(), $SpinRewriterWordPressPlugin_minimalRequiredPhpVersion) < 0) {
        add_action('admin_notices', 'SpinRewriterWordPressPlugin_noticePhpVersionWrong');
        return false;
    }
    return true;
}


/**
 * Initialize internationalization (i18n) for this plugin.
 * References:
 *      http://codex.wordpress.org/I18n_for_WordPress_Developers
 *      http://www.wdmac.com/how-to-create-a-po-language-translation#more-631
 * @return void
 */
function SpinRewriterWordPressPlugin_i18n_init() {
    $pluginDir = dirname(plugin_basename(__FILE__));
    load_plugin_textdomain('spin-rewriter-wordpress-plugin', false, $pluginDir . '/languages/');
}


//////////////////////////////////
// Run initialization
/////////////////////////////////

// First initialize i18n
SpinRewriterWordPressPlugin_i18n_init();


// Next, run the version check.
// If it is successful, continue with initialization for this plugin
if (SpinRewriterWordPressPlugin_PhpVersionCheck()) {
    // Only load and run the init function if we know PHP version can parse it
    include_once('spin-rewriter-wordpress-plugin_init.php');
    SpinRewriterWordPressPlugin_init(__FILE__);
}


// Finally, make sure this plugin knows how to auto-update itself.
try {
	include 'plugin-updates/plugin-update-checker.php';
	$MyUpdateChecker = PucFactory::buildUpdateChecker(
		'https://www.spinrewriter.com/wordpress/wordpress-plugin-metadata.json',
		__FILE__,
		'spin-rewriter-wordpress-plugin'
	);
} catch (Exception $e) {
	// Something went wrong with the initialization of the auto-updater library.
}
